from jimmypage.cache import cache_page

from django.http import Http404
from django.shortcuts import redirect, get_object_or_404, render

from .models import pre_route, post_route, Page


@cache_page
def page(request, url='/'):
    """Show a page.""" 
    try:
        def fix_url(url):
            if url[-1] != '/':
               url = url + '/'

            if url[0] != '/':
               url = '/' + url
            return url

        url = fix_url(url)
        page = get_object_or_404(Page, url=url)

        template = page.template_override
        if not template:
           template = 'page.html'
        return render(request, template, {
            'active': page,
            'page': page,
        }, content_type='text/html')
    except Http404:
        post_routes = post_route.send(sender=request, url=url)
        for reciever, response in post_routes:
            if response:
                return response
        raise Http404


from setuptools import setup, find_packages

requires = []
dep_links = []

for dep in open('requirements.txt').read().split("\n"):
    if dep.startswith('git+'):
        dep_links.append(dep)
    else:
        requires.append(dep)

setup(
    name='django-suave',
    version="0.5.17",
    description='Rather nice pages.',
    long_description=open('README.rst').read(),
    url='https://github.com/radiosilence/django-suave',
    author='James Cleveland',
    author_email='jamescleveland@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    license="LICENSE.txt",
    install_requires=requires,
    dependency_links=dep_links,
)
